@@ -18,4 +18,7 @@
 
 package terraformurl
 
-const PublicKey = "https://www.hashicorp.com/.well-known/pgp-key.txt"
+const (
+	Hashicorp = "https://releases.hashicorp.com"
+	PublicKey = "https://www.hashicorp.com/.well-known/pgp-key.txt"
+)
